==> jc-1.4.0.tar.gz: java/security/cert/CertPathValidatorSpi.h <==
// public abstract class java.security.cert.CertPathValidatorSpi

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f36fbe7f99064be7 java_security_cert_CertPathValidatorSpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_CertPathValidatorSpi_H_
#define _JC_java_security_cert_CertPathValidatorSpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_cert_CertPath$object;
struct _jc_java_security_cert_CertPathParameters$object;
struct _jc_java_security_cert_CertPathValidatorResult$object;

// Typedefs
typedef struct _jc_java_security_cert_CertPathValidatorSpi$sub_refs	_jc_java_security_cert_CertPathValidatorSpi$sub_refs;
typedef struct _jc_java_security_cert_CertPathValidatorSpi$sub_nonrefs	_jc_java_security_cert_CertPathValidatorSpi$sub_nonrefs;
typedef struct _jc_java_security_cert_CertPathValidatorSpi$refs	_jc_java_security_cert_CertPathValidatorSpi$refs;
typedef struct _jc_java_security_cert_CertPathValidatorSpi$nonrefs	_jc_java_security_cert_CertPathValidatorSpi$nonrefs;
typedef struct _jc_java_security_cert_CertPathValidatorSpi$object	_jc_java_security_cert_CertPathValidatorSpi$object;

typedef const struct _jc_java_security_cert_CertPathValidatorSpi$vmethods	_jc_java_security_cert_CertPathValidatorSpi$vmethods;
typedef const struct _jc_java_security_cert_CertPathValidatorSpi$vtable	_jc_java_security_cert_CertPathValidatorSpi$vtable;
typedef const struct _jc_java_security_cert_CertPathValidatorSpi$vtype	_jc_java_security_cert_CertPathValidatorSpi$vtype;

// Constructors
extern void _jc_java_security_cert_CertPathValidatorSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_cert_CertPathValidatorSpi$object *);

// Virtual methods
extern struct _jc_object *_jc_java_security_cert_CertPathValidatorSpi$method$engineValidate$38351e7608bca8b6(_jc_env *, struct _jc_java_security_cert_CertPathValidatorSpi$object *, struct _jc_java_security_cert_CertPath$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_CertPathValidatorSpi$method_info$engineValidate$38351e7608bca8b6;

// Virtual methods structure
struct _jc_java_security_cert_CertPathValidatorSpi$vmethods {
	struct _jc_object	*(*engineValidate$38351e7608bca8b6)(_jc_env *, struct _jc_java_security_cert_CertPathValidatorSpi$object *, struct _jc_java_security_cert_CertPath$object *, struct _jc_object *);
};

// Vtable
struct _jc_java_security_cert_CertPathValidatorSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_CertPathValidatorSpi$vmethods	java_security_cert_CertPathValidatorSpi;
};

// Vtype
struct _jc_java_security_cert_CertPathValidatorSpi$vtype {
	_jc_type			type;
	_jc_java_security_cert_CertPathValidatorSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_CertPathValidatorSpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_cert_CertPathValidatorSpi$refs {
    _jc_java_security_cert_CertPathValidatorSpi$sub_refs	java_security_cert_CertPathValidatorSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_CertPathValidatorSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_CertPathValidatorSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_CertPathValidatorSpi$sub_nonrefs	java_security_cert_CertPathValidatorSpi;
};

// Object instance structure
struct _jc_java_security_cert_CertPathValidatorSpi$object {
	_jc_java_security_cert_CertPathValidatorSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_CertPathValidatorSpi$vtype	*vtype;
	_jc_java_security_cert_CertPathValidatorSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_CertPathValidatorSpi$vtype _jc_java_security_cert_CertPathValidatorSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_CertPathValidatorSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_CertPathValidatorSpi$class_object;

#endif	/* _JC_java_security_cert_CertPathValidatorSpi_H_ */

==> jc-1.4.6.tar.gz: java/security/cert/CertPathValidatorSpi.h <==
// public abstract class java.security.cert.CertPathValidatorSpi

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f36fbe7f99064be7 java_security_cert_CertPathValidatorSpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_CertPathValidatorSpi_H_
#define _JC_java_security_cert_CertPathValidatorSpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_cert_CertPath$object;
struct _jc_java_security_cert_CertPathParameters$object;
struct _jc_java_security_cert_CertPathValidatorResult$object;

// Typedefs
typedef struct _jc_java_security_cert_CertPathValidatorSpi$sub_refs	_jc_java_security_cert_CertPathValidatorSpi$sub_refs;
typedef struct _jc_java_security_cert_CertPathValidatorSpi$sub_nonrefs	_jc_java_security_cert_CertPathValidatorSpi$sub_nonrefs;
typedef struct _jc_java_security_cert_CertPathValidatorSpi$refs	_jc_java_security_cert_CertPathValidatorSpi$refs;
typedef struct _jc_java_security_cert_CertPathValidatorSpi$nonrefs	_jc_java_security_cert_CertPathValidatorSpi$nonrefs;
typedef struct _jc_java_security_cert_CertPathValidatorSpi$object	_jc_java_security_cert_CertPathValidatorSpi$object;

typedef const struct _jc_java_security_cert_CertPathValidatorSpi$vmethods	_jc_java_security_cert_CertPathValidatorSpi$vmethods;
typedef const struct _jc_java_security_cert_CertPathValidatorSpi$vtable	_jc_java_security_cert_CertPathValidatorSpi$vtable;
typedef const struct _jc_java_security_cert_CertPathValidatorSpi$vtype	_jc_java_security_cert_CertPathValidatorSpi$vtype;

// Constructors
extern void _jc_java_security_cert_CertPathValidatorSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_cert_CertPathValidatorSpi$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_security_cert_CertPathValidatorSpi$method$engineValidate$38351e7608bca8b6(_jc_env *, struct _jc_java_security_cert_CertPathValidatorSpi$object *, struct _jc_java_security_cert_CertPath$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_CertPathValidatorSpi$method_info$engineValidate$38351e7608bca8b6;

// Virtual methods structure
struct _jc_java_security_cert_CertPathValidatorSpi$vmethods {
	struct _jc_object	*(*engineValidate$38351e7608bca8b6)(_jc_env *, struct _jc_java_security_cert_CertPathValidatorSpi$object *, struct _jc_java_security_cert_CertPath$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_cert_CertPathValidatorSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_CertPathValidatorSpi$vmethods	java_security_cert_CertPathValidatorSpi;
};

// Vtype
struct _jc_java_security_cert_CertPathValidatorSpi$vtype {
	_jc_type			type;
	_jc_java_security_cert_CertPathValidatorSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_CertPathValidatorSpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_cert_CertPathValidatorSpi$refs {
    _jc_java_security_cert_CertPathValidatorSpi$sub_refs	java_security_cert_CertPathValidatorSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_CertPathValidatorSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_CertPathValidatorSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_CertPathValidatorSpi$sub_nonrefs	java_security_cert_CertPathValidatorSpi;
};

// Object instance structure
struct _jc_java_security_cert_CertPathValidatorSpi$object {
	_jc_java_security_cert_CertPathValidatorSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_CertPathValidatorSpi$vtype	*vtype;
	_jc_java_security_cert_CertPathValidatorSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_CertPathValidatorSpi$vtype _jc_java_security_cert_CertPathValidatorSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_CertPathValidatorSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_CertPathValidatorSpi$class_object;

#endif	/* _JC_java_security_cert_CertPathValidatorSpi_H_ */
